@@ -15,7 +15,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Glib.pm,v 1.120 2008/03/30 17:26:01 kaffeetisch Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Glib.pm,v 1.123 2008/08/18 20:46:09 kaffeetisch Exp $
 #
 
 package Glib;
@@ -63,7 +63,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = map { @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 
-our $VERSION = '1.182';
+our $VERSION = '1.191';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
@@ -76,7 +76,8 @@ use overload
    '+'    => \&union,     '|'    => \&union,
    '-'    => \&sub,
    '>='   => \&ge,
-   '=='   => \&eq,        'eq'   => \&eq, # eq for is_deeply in Test::More
+   '=='   => \&eq,        'eq'   => \&eq,
+   '!='   => \&ne,        'ne'   => \&ne,
    '*'    => \&intersect, '&'    => \&intersect,
    '/'    => \&xor,       '^'    => \&xor,
    '@{}'  => \&as_arrayref,
